* Output options: all can be turned on/off by adding or removing the NO;
* page number, date, centering, or page breaks, page length and width;
OPTIONS NOnumber NOdate NOcenter FormDlim=' ' PageSize=MAX LineSize=MAX;
* Eliminate SAS default titles and names of tables in output (TRACE ON to show);
TITLE; ODS TRACE OFF; ODS LISTING;

***********************************************************************************;
*******                  BEGIN DATA MANIPULATION FOR EXAMPLE 5              *******;
*******                  CHANGE "filesave" to your directory                *******;
***********************************************************************************;

* Defining global variable for file location to be replaced in code below;
%LET filesave= C:\Dropbox\14_SPLH861\861_Example5;
* Location for SAS files for these models (uses macro variable filesave);
LIBNAME filesave "&filesave.";

* Import example 5 multivariate data into work library and stack it;
DATA work.Example5; SET filesave.SAS_Example5; 
	condition=1; mean=1; sal=1; rt=rt11; OUTPUT; * Low  meaning, low  salience;
	condition=2; mean=1; sal=2; rt=rt12; OUTPUT; * Low  meaning, high salience;
	condition=3; mean=2; sal=1; rt=rt21; OUTPUT; * High meaning, low  salience;
	condition=4; mean=2; sal=2; rt=rt22; OUTPUT; * High meaning, high salience;
* Label new stacked variables;
LABEL condition= "condition: Index for Outcome (1-4)"
      mean= "Meaning (1=Low, 2=High)" 
	  sal= "Salience (1=Low, 2=High)"
	  rt= "rt: Combined Response Time across Conditions";
* Drop old multivariate outcomes;
	DROP rt11--rt22;
RUN;

* Create format (like value label) to use for condition variables;
PROC FORMAT; VALUE fcondition 1="1Low" 2="2High"; RUN;

* Create variables for analysis;
 DATA work.Example5; SET work.Example5; 
* Log RT to improve residual normality;
  logRT=LOG(RT);  
* Format condition variables;
  FORMAT mean sal fcondition.; 
* Create piecewise effects of age;
       IF old=0 THEN yrs65=0;      
  ELSE IF old=1 THEN yrs65=age-65; 
* Label new variables;
  LABEL logrt= "logRT: Natural Log of Response Time"
        yrs65= "yrs65: Age in Older Adult Group (0=65)";
RUN;

********************************************************************************;
*******                      BEGIN EXAMPLE 5 MODELS                      *******;
********************************************************************************;

* Open output directory to save results to;
ODS RTF FILE="&filesave.\SAS_Example5_Output.rtf" STYLE=HTMLBlue STARTPAGE=NO;

TITLE1 "SAS Empty Multivariate Model: RT Mean Differences for Meaning by Salience";
TITLE2 "Unstructured R Matrix";
PROC MIXED DATA=work.Example5 COVTEST NOCLPRINT NAMELEN=100 IC METHOD=REML;
	CLASS PersonID condition mean sal; 
	MODEL logRT = mean|sal@2 / SOLUTION DDFM=Satterthwaite;
	REPEATED condition / R RCORR TYPE=UN SUBJECT=PersonID; 
RUN; TITLE1; TITLE2;

TITLE1 "SAS Empty Multivariate Model: RT Mean Differences for Meaning by Salience";
TITLE2 "Compound Symmetry R Matrix";
PROC MIXED DATA=work.Example5 COVTEST NOCLPRINT NAMELEN=100 IC METHOD=REML;
	CLASS PersonID condition mean sal; 
	MODEL logRT = mean|sal@2 / SOLUTION DDFM=Satterthwaite;	 
	REPEATED condition / R RCORR TYPE=CS SUBJECT=PersonID; 
RUN; TITLE1; TITLE2;

TITLE1 "SAS Conditional Multivariate Model: Age Age Group and Years over 65";
TITLE2 "Unstructured R Matrix";
PROC MIXED DATA=work.Example5 COVTEST NOCLPRINT NAMELEN=100 IC METHOD=REML;
	CLASS PersonID condition mean sal; 
	MODEL logRT = mean|sal|old@3 mean|sal|yrs65@3 / SOLUTION CHISQ DDFM=Satterthwaite;
	REPEATED condition / R RCORR TYPE=UN SUBJECT=PersonID; 
RUN; TITLE1; TITLE2;

TITLE1 "SAS Reduced Conditional Multivariate Model: Years over 65 as Main Effect";
TITLE2 "Unstructured R Matrix";
PROC MIXED DATA=work.Example5 COVTEST NOCLPRINT NAMELEN=100 IC METHOD=REML;
	CLASS PersonID condition mean sal; 
	MODEL logRT = mean|sal|old@3 yrs65 / SOLUTION CHISQ DDFM=Satterthwaite;
	REPEATED condition / R RCORR TYPE=UN SUBJECT=PersonID; 
* Getting condition means and simple effect tests at different ages;
	LSMEANS mean*sal / AT (old yrs65)=(0  0) SLICE=mean SLICE=sal; * For YA;
	LSMEANS mean*sal / AT (old yrs65)=(1  0) SLICE=mean SLICE=sal; * For age 65;
	LSMEANS mean*sal / AT (old yrs65)=(1 10) SLICE=mean SLICE=sal; * For age 75;
* Getting age group differences per condition -- need all terms with old slope in them;
    ESTIMATE "Old: Low Mean,  Low Sal"  old 1 mean*old 1 0 sal*old 1 0 mean*sal*old 1 0 0 0;
    ESTIMATE "Old: Low Mean,  High Sal" old 1 mean*old 1 0 sal*old 0 1 mean*sal*old 0 1 0 0;
    ESTIMATE "Old: High Mean, Low Sal"  old 1 mean*old 0 1 sal*old 1 0 mean*sal*old 0 0 1 0;
    ESTIMATE "Old: High Mean, High Sal" old 1 mean*old 0 1 sal*old 0 1 mean*sal*old 0 0 0 1;
RUN; TITLE1; TITLE2;

* Close output;
ODS RTF CLOSE;
