* Stop syntax and large titles from printing to output.
SET PRINTBACK=NONE HEADER=NO.

***********************************************************************************.
*******                BEGIN DATA MANIPULATION FOR EXAMPLE 5                *******.
*******                CHANGE "filesave" to your directory                  *******.
***********************************************************************************.

* Define location of files used in code below.
FILE HANDLE filesave /NAME = "C:\Dropbox\14_SPLH861\861_Example5".
* Import example 5 multivariate data into work library and stack it.
GET FILE = "filesave/SPSS_Example5.sav".
DATASET NAME Example5 WINDOW=FRONT.
VARSTOCASES
   /MAKE rt FROM rt11 rt12 rt21 rt22
   /INDEX = condition (4)
   /KEEP = ALL.
* Create condition variables.
DO IF (condition=1).
COMPUTE mean=1.
COMPUTE sal=1.
END IF.
DO IF (condition=2).
COMPUTE mean=1.
COMPUTE sal=2.
END IF.
DO IF (condition=3).
COMPUTE mean=2.
COMPUTE sal=1.
END IF.
DO IF (condition=4).
COMPUTE mean=2.
COMPUTE sal=2.
END IF.
* Label new stacked variables.
VARIABLE LABELS
condition "condition: Index for Outcome (1-4)"
mean "Meaning (1=Low, 2=High)" 
sal "Salience (1=Low, 2=High)"
rt "rt: Combined Response Time across Conditions".
* Create value labels for conditon variables.
VALUE LABELS mean sal 1 "1Low" 2 "2High".
 
* Create variables for analysis.
COMPUTE logrt=LN(rt).
IF (old=0) yrs65=0.
IF (old=1) yrs65=age-65.
* Label new variables.
VARIABLE LABELS 
logrt "logRT: Natural Log of Response Time"
yrs65 "yrs65: Age in Older Adult Group (0=65)".
EXECUTE.

***********************************************************************************.
*******                       BEGIN EXAMPLE 5 MODELS                        *******.
***********************************************************************************.

* Open output directory.
OUTPUT NAME SPSS_Example5_Output.

ECHO 'SPSS Empty Multivariate Model: RT Mean Differences for Meaning by Salience;'.
ECHO 'Unstructured R Matrix'.
MIXED logrt BY PersonID condition mean sal
     /METHOD   = REML
     /PRINT    = SOLUTION TESTCOV R
     /FIXED    = mean sal mean*sal
     /REPEATED = condition | COVTYPE(UN) SUBJECT(PersonID).

ECHO 'SPSS Empty Multivariate Model: RT Mean Differences for Meaning by Salience;'.
ECHO 'Compound Symmetry R Matrix'.
MIXED logrt BY PersonID condition mean sal
     /METHOD   = REML
     /PRINT    = SOLUTION TESTCOV R
     /FIXED    = mean sal mean*sal
     /REPEATED = condition | COVTYPE(CS) SUBJECT(PersonID).

ECHO 'SPSS Conditional Multivariate Model: Add Age Group and Years over 65;'.
ECHO 'Unstructured R Matrix'.
MIXED logrt BY PersonID condition mean sal WITH old yrs65
     /METHOD   = REML
     /PRINT    = SOLUTION TESTCOV R
     /FIXED    = mean sal mean*sal old old*mean old*sal old*mean*sal
                 yrs65 yrs65*mean yrs65*sal yrs65*mean*sal
     /REPEATED = condition | COVTYPE(UN) SUBJECT(PersonID).

ECHO 'SPSS Reduced Conditional Multivariate Model: Years over 65 as Main Effect;'.
ECHO 'Unstructured R Matrix'.
MIXED logrt BY PersonID condition mean sal WITH old yrs65
     /METHOD   = REML
     /PRINT    = SOLUTION TESTCOV R
     /FIXED    = mean sal mean*sal old old*mean old*sal old*mean*sal yrs65 
     /REPEATED = condition | COVTYPE(UN) SUBJECT(PersonID)
     /EMMEANS  = TABLES(mean*sal) COMPARE(mean) WITH(old=0 yrs65=0)   
     /EMMEANS  = TABLES(mean*sal) COMPARE(mean) WITH(old=1 yrs65=0) 
     /EMMEANS  = TABLES(mean*sal) COMPARE(mean) WITH(old=1 yrs65=10)    
     /EMMEANS  = TABLES(mean*sal) COMPARE(sal)  WITH(old=0 yrs65=0)   
     /EMMEANS  = TABLES(mean*sal) COMPARE(sal)  WITH(old=1 yrs65=0) 
     /EMMEANS  = TABLES(mean*sal) COMPARE(sal)  WITH(old=1 yrs65=10)
     /TEST = "Old: Low Mean,  Low Sal"  old 1 mean*old 1 0 sal*old 1 0 mean*sal*old 1 0 0 0
     /TEST = "Old: Low Mean,  High Sal" old 1 mean*old 1 0 sal*old 0 1 mean*sal*old 0 1 0 0
     /TEST = "Old: High Mean, Low Sal"  old 1 mean*old 0 1 sal*old 1 0 mean*sal*old 0 0 1 0
     /TEST = "Old: High Mean, High Sal" old 1 mean*old 0 1 sal*old 0 1 mean*sal*old 0 0 0 1.

* Close and export output directory.
OUTPUT EXPORT
  /CONTENTS  EXPORT=VISIBLE  LAYERS=VISIBLE  MODELVIEWS=VISIBLE
  /DOC  DOCUMENTFILE="filesave\SPSS_Example5_Output.doc"
     NOTESCAPTIONS=YES  WIDETABLES=WRAP PAGEBREAKS=YES
     PAGESIZE=INCHES(8.5, 11.0)  TOPMARGIN=INCHES(1.0)  BOTTOMMARGIN=INCHES(1.0)
     LEFTMARGIN=INCHES(1.0)  RIGHTMARGIN=INCHES(1.0).

