* Prevent "more" messages from appearing
set more off
* Control line length
set linesize 150

********************************************************************************
*******             BEGIN DATA MANIPULATION FOR EXAMPLE 5                *******
*******             CHANGE "filesave" to your directory                  *******
********************************************************************************

* Defining global variable for file location to be replaced in code below
global filesave "C:\Dropbox\14_SPLH861\861_Example5"

* Import example 5 multivariate data into work library and stack it
* List multivariate variables first, i(personID) j(condition)
use "$filesave\STATA_Example5.dta", clear
reshape long rt, i(personid) j(condition)
* Create condition variables
gen mean=1
gen sal=1
recode mean (1=2) if condition==21
recode mean (1=2) if condition==22
recode sal  (1=2) if condition==12
recode sal  (1=2) if condition==22
* Label new stacked variables
label variable condition "condition: Index for Outcome"
label variable mean "Meaning (1=Low, 2=High)" 
label variable sal "Salience (1=Low, 2=High)" 
label variable rt "rt: Combined Response Time across Conditions"
* Create value labels for condition variables
label define fcondition 1 "1Low" 2 "2High" 
label values mean sal fcondition 
* Create variables for analysis
gen logrt=ln(rt)
gen yrs65=0
replace yrs65=age-65 if old==1
* Label new variables
label variable logrt "logRT: Natural Log of Response Time"
label variable yrs65 "yrs65: Age in Older Adult Group (0=65)"

********************************************************************************
*******                      BEGIN EXAMPLE 5 MODELS                      *******
********************************************************************************

* Save results to separate file
log using $filesave\STATA_Example5_Output.log, replace name(STATA_Example5)

display as result "STATA Empty Multivariate Model"
display as result "RT Mean Differences for Meaning by Salience"
display as result "Unstructured R Matrix"
mixed logrt ib(last).mean##ib(last).sal, ///
         || personid: , noconstant variance reml ///
         residuals(unstructured,t(condition)),
      estat ic, n(156),
      estat wcorrelation, covariance,
      estat wcorrelation,
      estimates store UN
	  
display as result "Empty Multivariate Model"
display as result "RT Mean Differences for Meaning by Salience"
display as result "Compound Symmetry R Matrix"
mixed logrt ib(last).mean##ib(last).sal, ///
         || personid: , noconstant variance reml ///
         residuals(exchangeable,t(condition)),
      estat ic, n(156),
      estat wcorrelation, covariance,
      estat wcorrelation,
	  estimates store CS,
	  lrtest UN CS

display as result "STATA Conditional Multivariate Model:"
display as result "Add Age Group and Years over 65"
display as result "Unstructured R Matrix"
mixed logrt ib(last).mean##ib(last).sal##c.old    ///
            ib(last).mean##ib(last).sal##c.yrs65, ///
         || personid: , noconstant variance reml  ///
         residuals(unstructured,t(condition)),
      estat ic, n(156),
      estat wcorrelation, covariance,
      estat wcorrelation,

display as result "STATA Reduced Conditional Multivariate Model:"
display as result "Years over 65 as Main Effect"
display as result "Unstructured R Matrix"
mixed logrt ib(last).mean##ib(last).sal##c.old c.yrs65, ///
         || personid: , noconstant variance reml  ///
         residuals(unstructured,t(condition)),
      estat ic, n(156),
      estat wcorrelation, covariance,
      estat wcorrelation,
	  margins ib(last).mean#ib(last).sal, at(c.old=0 c.yrs65=0) 
	  margins ib(last).mean#ib(last).sal, at(c.old=1 c.yrs65=0) 
	  margins ib(last).mean#ib(last).sal, at(c.old=1 c.yrs65=10)
	  margins ib(last).mean@ib(last).sal, at(c.old=0 c.yrs65=0) 
	  margins ib(last).mean@ib(last).sal, at(c.old=1 c.yrs65=0) 
	  margins ib(last).mean@ib(last).sal, at(c.old=1 c.yrs65=10)
	  margins ib(last).sal@ib(last).mean, at(c.old=0 c.yrs65=0) 
	  margins ib(last).sal@ib(last).mean, at(c.old=1 c.yrs65=0) 
	  margins ib(last).sal@ib(last).mean, at(c.old=1 c.yrs65=10)
	  lincom c.old*1 + i1.mean#c.old*1 + i1.sal#c.old*1 + i1.mean#i1.sal#c.old*1
	  lincom c.old*1 + i1.mean#c.old*1 + i2.sal#c.old*1 + i1.mean#i2.sal#c.old*1
	  lincom c.old*1 + i2.mean#c.old*1 + i1.sal#c.old*1 + i2.mean#i1.sal#c.old*1
	  lincom c.old*1 + i2.mean#c.old*1 + i2.sal#c.old*1 + i2.mean#i2.sal#c.old*1
	  
* Close log
log close STATA_Example5
